summaryrefslogtreecommitdiff
path: root/src/mongo/db/namespace_string.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/namespace_string.h')
-rw-r--r--src/mongo/db/namespace_string.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/db/namespace_string.h b/src/mongo/db/namespace_string.h
index 881b9e1d468..9a7e54500cf 100644
--- a/src/mongo/db/namespace_string.h
+++ b/src/mongo/db/namespace_string.h
@@ -139,14 +139,14 @@ public:
bool isNormal() const {
return normal(_ns);
}
- bool isListCollectionsGetMore() const;
- bool isListIndexesGetMore() const;
+ bool isListCollectionsCursorNS() const;
+ bool isListIndexesCursorNS() const;
/**
* Given a NamespaceString for which isListIndexesGetMore() returns true, returns the
* NamespaceString for the collection that the "listIndexesGetMore" targets.
*/
- NamespaceString getTargetNSForListIndexesGetMore() const;
+ NamespaceString getTargetNSForListIndexes() const;
/**
* @return true if the namespace is valid. Special namespaces for internal use are considered as
@@ -139,14 +139,14 @@ public:
/**
- * Given a NamespaceString for which isListIndexesGetMore() returns true, returns the
- * NamespaceString for the collection that the "listIndexesGetMore" targets.
+ * Given a NamespaceString for which isListIndexesCursorNS() returns true, returns the
+ * NamespaceString for the collection that the "listIndexes" targets.
*/